pub(super) async fn notify_model_added(
environment: &MountainEnvironment,
document_state_dto: &Value,
)Expand description
Notifies Cocoon that a new document model has been added.
pub(super) async fn notify_model_added(
environment: &MountainEnvironment,
document_state_dto: &Value,
)Notifies Cocoon that a new document model has been added.