pub(super) async fn notify_model_removed(
environment: &MountainEnvironment,
uri: &Url,
)Expand description
Notifies Cocoon that a document has been closed or renamed.
pub(super) async fn notify_model_removed(
environment: &MountainEnvironment,
uri: &Url,
)Notifies Cocoon that a document has been closed or renamed.