pub(super) async fn notify_model_saved(
environment: &MountainEnvironment,
uri: &Url,
)Expand description
Notifies Cocoon that a document has been saved to disk.
pub(super) async fn notify_model_saved(
environment: &MountainEnvironment,
uri: &Url,
)Notifies Cocoon that a document has been saved to disk.